=== modified file 'Makefile'
--- Makefile	2009-06-19 09:06:56 +0000
+++ Makefile	2009-07-02 08:26:00 +0000
@@ -90,6 +90,7 @@
 	doc/en/user-guide/index.txt \
 	doc/en/mini-tutorial/index.txt \
 	doc/en/developer-guide/HACKING.txt \
+	doc/en/upgrade-guide/index.txt \
 	$(wildcard doc/es/guia-usario/*.txt) \
 	doc/es/mini-tutorial/index.txt \
 	doc/index.txt \
@@ -143,6 +144,9 @@
 doc/%/user-guide/index.html: $(wildcard $(addsuffix /*.txt, doc/%/user-guide)) 
 	$(rst2html) --stylesheet=../../default.css $(dir $@)index.txt $@
 
+doc/%/upgrade-guide/index.html: $(wildcard $(addsuffix /*.txt, doc/%/upgrade-guide)) 
+	$(rst2html) --stylesheet=../../default.css $(dir $@)index.txt $@
+
 # Set the paper size for PDF files.
 # Options:  'a4' (ISO A4 size), 'letter' (US Letter size)
 PAPERSIZE = a4

=== added directory 'doc/en/upgrade-guide'
=== added file 'doc/en/upgrade-guide/data_migration.txt'
--- doc/en/upgrade-guide/data_migration.txt	1970-01-01 00:00:00 +0000
+++ doc/en/upgrade-guide/data_migration.txt	2009-07-02 08:26:00 +0000
@@ -0,0 +1,61 @@
+Data migration
+##############
+
+Preparing for data migration
+----------------------------
+
+Before starting a migration, there are a few important things to do
+first:
+
+1. Take a complete backup.
+
+2. Take some time to purge obsolete branches.
+
+A complete backup gives you a safety net in case anything goes wrong.
+
+Purging obsolete branches reduces the amount of data that needs to
+be migrated. See `Finding obsolete branches`_ later for some tips
+on doing this.
+
+
+Introducing the upgrade-related commands
+----------------------------------------
+
+There are 3 important commands to be aware of when migrating data.
+
+* **check** - check a repository, branch or tree for data integrity errors
+
+* **reconcile** - fix data integrity errors
+
+* **upgrade** - migrate data to a different format.
+
+**reconcile** is rarely needed but it's good practice to run **check**
+before runing **upgrade**.
+
+For detailed help on these commands, see the Bazaar User Reference.
+
+.. _Bazaar User Reference: ../user-reference/index.html
+
+
+Migrating a standalone branch
+-----------------------------
+
+To do ...
+
+
+Migrating branches in a shared repository
+-----------------------------------------
+
+To do ...
+
+
+Migrating stacked branches
+--------------------------
+
+All branches stacked on another branch need to be upgraded **before**
+the stacked on branch. For branches managed on Launchpad, the default
+policy is for branches to be stacked on trunk so that means that you
+need to give your community plenty of time to upgrade any branches
+they own on Launchpad before you schedule the trunk upgrade.
+
+To be completed ...

=== added file 'doc/en/upgrade-guide/index.txt'
--- doc/en/upgrade-guide/index.txt	1970-01-01 00:00:00 +0000
+++ doc/en/upgrade-guide/index.txt	2009-07-02 08:26:00 +0000
@@ -0,0 +1,19 @@
+########################
+Bazaar 2.0 Upgrade Guide
+########################
+
+.. Files are currently links but will become includes once the
+.. content makes more sense as a whole.
+.. Please mark sections in linked/included files as following:
+..   level 1 ========
+..   level 2 --------
+..   level 3 ~~~~~~~~
+..   level 4 ^^^^^^^^ (it is better not to use nesting deeper than 3 levels)
+
+.. contents:: :depth: 2
+.. sectnum::
+
+
+.. include:: overview.txt
+.. include:: data_migration.txt
+.. include:: tips_and_tricks.txt

=== added file 'doc/en/upgrade-guide/overview.txt'
--- doc/en/upgrade-guide/overview.txt	1970-01-01 00:00:00 +0000
+++ doc/en/upgrade-guide/overview.txt	2009-07-02 08:26:00 +0000
@@ -0,0 +1,93 @@
+Overview
+########
+
+High Level Upgrade Process
+--------------------------
+
+In broad terms, there are 3 steps involved in upgrading to Bazaar 2.x:
+
+1. Upgrade the core software
+
+2. Upgrade required plugins
+
+3. Migrate data to the new default format.
+
+Bazaar 2.x supports branches in earlier formats so the third step is
+strictly not required. However, the new default format in Bazaar 2.x
+is more space efficient, faster on large projects and provides a range
+of new features, so it is recommended that most projects migrate to it
+at a convenient time.
+
+For most users, upgrading to 2.x and migrating to the new format is
+straight forward. For projects with a large community of developers
+though, things become more complex. In these cases, careful planning
+and good communications become essential. This document provides
+general advice which aims to assist in this regard. If in doubt,
+please contact us on our mailing list or IRC channel with any
+questions or concerns you have.
+
+
+Upgrading the core software
+---------------------------
+
+The steps required to upgrade the core software vary from operating
+system to operating system. There is nothing special about upgrading
+from Bazaar 1.x to Bazaar 2.0 compared to upgrading from Bazaar 1.x
+to Bazaar 1.y. In either case, a brief outline of the steps is given
+below.
+
+To upgrade Bazaar on Linux:
+
+1. Ensure your package manager is configured with the required
+   software sources, e.g. the official release PPA for Ubuntu:
+   https://launchpad.net/~bzr/+archive
+
+2. Use your package manager to upgrade to the latest version.
+
+To upgrade Bazaar on Windows:
+
+1. Uninstall the existing version using Add/Remove Programs.
+
+2. Install the new version using the relevant installer.
+
+To upgrade Bazaar on OS X (via the installer):
+
+1. Uninstall the existing version by deleting the relevant
+   application folder.
+
+2. Install the new version using the relevant installer.
+
+To upgrade Bazaar on OS X (via MacPorts):
+
+1. Refresh the package metadata using **sudo port selfupdate**
+
+2. Upgrade to the latest version using **sudo port upgrade bzr**
+
+For further information of installing and upgrading, see
+http://bazaar-vcs.org/Download.
+
+
+Upgrading required plugins
+--------------------------
+
+Many plugins are not dependent on a particular Bazaar version so
+upgrading them is optional. Other plugins, notably bzrtools and
+bzr-svn, are more tightly associated with Bazaar's APIs so these
+typically need to be upgraded in lockstep with the core software.
+
+For Windows and OS X users, bzrtools and bzr-svn are typically
+included in the installer so no special steps are required to upgrade
+these. For Linux and UNIX users, bztrools, bzr-svn and many other
+popular plugins can be installed and upgraded using your
+platform's package manager, e.g. Synaptic on Ununtu.
+
+
+Migrating data to the new default format
+----------------------------------------
+
+As mentioned earlier, the complexity of migrating to a new format
+depends on several factors, particularly project community size.
+It also depends on how data is currently stored, e.g. in a
+standalone branch, multiple branches in a shared repository,
+stacked branches on Launchpad, etc. These various scenarios are
+covered in the next chapter.

=== added file 'doc/en/upgrade-guide/tips_and_tricks.txt'
--- doc/en/upgrade-guide/tips_and_tricks.txt	1970-01-01 00:00:00 +0000
+++ doc/en/upgrade-guide/tips_and_tricks.txt	2009-07-02 08:26:00 +0000
@@ -0,0 +1,31 @@
+Tips and tricks
+###############
+
+Finding obsolete branches
+-------------------------
+
+If you use feature branching for developing each fix
+and enhancement separately, you may have several old
+branches that are no longer required. In many cases,
+the relevant changes may now be merged into trunk.
+In other cases, a branch may be obsolete thanks to
+another change made by yourself or others.
+
+When checking for an obsolete branch, there are two
+things in particular to confirm:
+
+1. The working tree has no in-progress changes.
+
+2. Any locally committed revisions have been merged
+   to the parent branch.
+
+After changing into the root of a branch, the commands
+to check these things respectively are::
+
+  bzr status
+  bzr missing --mine-only
+
+If your branches are stored in a shared repository locally,
+you may find the *Local Changes* tab in Bazaar Explorer's
+repository view helpful here as it shows a summary of
+these things for each branch as you select it.

=== modified file 'doc/index.txt'
--- doc/index.txt	2009-06-01 22:45:06 +0000
+++ doc/index.txt	2009-07-02 08:26:00 +0000
@@ -19,6 +19,8 @@
 
 * `Release Notes <en/release-notes/NEWS.html>`_
 
+* `2.0 Upgrade Guide <en/upgrade-guide/index.html>`_ 
+
 * `Developer Document Catalog <developers/index.html>`_ |--| for developers
   of Bazaar and plugins
 

